aboutsummaryrefslogtreecommitdiff
path: root/dev/create-release/release-build.sh
diff options
context:
space:
mode:
Diffstat (limited to 'dev/create-release/release-build.sh')
-rwxr-xr-xdev/create-release/release-build.sh14
1 files changed, 7 insertions, 7 deletions
diff --git a/dev/create-release/release-build.sh b/dev/create-release/release-build.sh
index 00bf81120d..2fd7fcc39e 100755
--- a/dev/create-release/release-build.sh
+++ b/dev/create-release/release-build.sh
@@ -134,9 +134,9 @@ if [[ "$1" == "package" ]]; then
cd spark-$SPARK_VERSION-bin-$NAME
- # TODO There should probably be a flag to make-distribution to allow 2.11 support
- if [[ $FLAGS == *scala-2.11* ]]; then
- ./dev/change-scala-version.sh 2.11
+ # TODO There should probably be a flag to make-distribution to allow 2.10 support
+ if [[ $FLAGS == *scala-2.10* ]]; then
+ ./dev/change-scala-version.sh 2.10
fi
export ZINC_PORT=$ZINC_PORT
@@ -228,8 +228,8 @@ if [[ "$1" == "publish-snapshot" ]]; then
$MVN -DzincPort=$ZINC_PORT --settings $tmp_settings -DskipTests $PUBLISH_PROFILES \
-Phive-thriftserver deploy
- ./dev/change-scala-version.sh 2.11
- $MVN -DzincPort=$ZINC_PORT -Dscala-2.11 --settings $tmp_settings \
+ ./dev/change-scala-version.sh 2.10
+ $MVN -DzincPort=$ZINC_PORT -Dscala-2.10 --settings $tmp_settings \
-DskipTests $PUBLISH_PROFILES clean deploy
# Clean-up Zinc nailgun process
@@ -266,9 +266,9 @@ if [[ "$1" == "publish-release" ]]; then
$MVN -DzincPort=$ZINC_PORT -Dmaven.repo.local=$tmp_repo -DskipTests $PUBLISH_PROFILES \
-Phive-thriftserver clean install
- ./dev/change-scala-version.sh 2.11
+ ./dev/change-scala-version.sh 2.10
- $MVN -DzincPort=$ZINC_PORT -Dmaven.repo.local=$tmp_repo -Dscala-2.11 \
+ $MVN -DzincPort=$ZINC_PORT -Dmaven.repo.local=$tmp_repo -Dscala-2.10 \
-DskipTests $PUBLISH_PROFILES clean install
# Clean-up Zinc nailgun process